@@ -32,7 +32,7 @@
          * Normalize the requested_value to the kernel_value, if it look as if a rounding
          * error happens. If the difference is larger than +/- 1, no normalization happens! */   \
                                                                                                  \
-        ((_requested_value >= (NM_MAX(_kernel_value, 1) - 1))                                    \
+        ((_requested_value >= (NM_MAX(_kernel_value, (typeof(_kernel_value)) 1) - 1))            \
          && (_requested_value <= (NM_MIN(_kernel_value, ~((typeof(_kernel_value)) 0) - 1) + 1))) \
             ? _kernel_value                                                                      \
             : _requested_value;                                                                  \
@@ -139,7 +139,10 @@ int nmtstp_run_command(const char *format, ...) _nm_printf(1, 2);
 
 /*****************************************************************************/
 
-void nmtstp_assert_platform(NMPlatform *platform, guint32 obj_type_flags);
+gboolean
+nmtstp_check_platform_full(NMPlatform *platform, guint32 obj_type_flags, gboolean do_assert);
+
+void nmtstp_check_platform(NMPlatform *platform, guint32 obj_type_flags);
 
 /*****************************************************************************/
 
@@ -530,6 +533,10 @@ void nmtstp_link_delete(NMPlatform *platform,
                         const char *name,
                         gboolean    require_exist);
 
+gboolean nmtstp_link_is_iptunnel_special(const NMPlatformLink *link);
+
+gboolean nmtstp_ensure_module(const char *module_name);
+
 /*****************************************************************************/
 
 #define nmtst_object_new_mptcp_addr(...) \
