@@ -614,9 +614,9 @@ verify(NMSetting *setting, NMConnection *connection, GError **error)
             if (s_con) {
                 const char *master = NULL, *slave_type = NULL;
 
-                slave_type = nm_setting_connection_get_slave_type(s_con);
+                slave_type = nm_setting_connection_get_port_type(s_con);
                 if (!g_strcmp0(slave_type, NM_SETTING_VLAN_SETTING_NAME))
-                    master = nm_setting_connection_get_master(s_con);
+                    master = nm_setting_connection_get_controller(s_con);
 
                 if (master && g_strcmp0(priv->parent, master) != 0) {
                     g_set_error(error,
@@ -872,7 +872,8 @@ nm_setting_vlan_class_init(NMSettingVlanClass *klass)
                                               PROP_PARENT,
                                               NM_SETTING_PARAM_INFERRABLE,
                                               NMSettingVlanPrivate,
-                                              parent);
+                                              parent,
+                                              .direct_string_allow_empty = TRUE);
 
     /**
      * NMSettingVlan:id:
@@ -963,7 +964,8 @@ nm_setting_vlan_class_init(NMSettingVlanClass *klass)
                                               NM_SETTING_PARAM_INFERRABLE,
                                               NMSettingVlanPrivate,
                                               protocol,
-                                              .direct_string_is_refstr = TRUE);
+                                              .direct_string_is_refstr   = TRUE,
+                                              .direct_string_allow_empty = TRUE);
 
     /**
      * NMSettingVlan:ingress-priority-map:
